@@ -35,7 +35,7 @@ class Domoticz(IPlugin):
 		bodies = ""
 		entity = jsonInput['outcome']['intent']
 		log.msg("entity :  %s" % (entity))		
-		if entity ="dz_loc_bureau_deux" or entity ="dz_loc_bureau_un" or entity ="dz_loc_carrillon" or entity ="dz_loc_salon"  :
+		if entity == "dz_loc_bureau_deux" or entity == "dz_loc_bureau_un" or entity == "dz_loc_carrillon" or entity == "dz_loc_salon"  :
 			on_off = jsonInput['outcome']['entities']['on_off']['value']
 			location = "VIDE"
 		if entity ="dz_loc_frisquet"  :
